summaryrefslogtreecommitdiff
path: root/xmlPivotCache.go
diff options
context:
space:
mode:
authorxuri <xuri.me@gmail.com>2019-09-16 01:17:35 +0800
committerxuri <xuri.me@gmail.com>2019-09-16 01:17:35 +0800
commit8922f659788187afa6d0a5d3248e999c2c1bb846 (patch)
tree29b2aae2028eaedc448daef08a5670d6f3ca4604 /xmlPivotCache.go
parenta3ee098ab60d9528a0d6b7a7c475ea8ff7ebaba5 (diff)
Combine functions:
workBookRelsWriter, drawingRelsWriter into relsWriter; drawingRelsReader, workbookRelsReader, workSheetRelsReader into relsReader; addDrawingRelationships, addSheetRelationships into addRels
Diffstat (limited to 'xmlPivotCache.go')
-rw-r--r--xmlPivotCache.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmlPivotCache.go b/xmlPivotCache.go
index 9e07931..0c00832 100644
--- a/xmlPivotCache.go
+++ b/xmlPivotCache.go
@@ -2,11 +2,11 @@ package excelize
import "encoding/xml"
// pivotCacheDefinition represents the pivotCacheDefinition part. This part
// defines each field in the source data, including the name, the string
// resources of the instance data (for shared items), and information about
// the type of data that appears in the field.
-type xmlPivotCacheDefinition struct {
+type xlsxPivotCacheDefinition struct {
XMLName xml.Name `xml:"http://schemas.openxmlformats.org/spreadsheetml/2006/main pivotCacheDefinition"`
RID string `xml:"http://schemas.openxmlformats.org/officeDocument/2006/relationships id,attr,omitempty"`
Invalid bool `xml:"invalid,attr,omitempty"`
@@ -2,11 +2,11 @@ package excelize
import "encoding/xml"
-// pivotCacheDefinition represents the pivotCacheDefinition part. This part
+// xlsxPivotCacheDefinition represents the pivotCacheDefinition part. This part
// defines each field in the source data, including the name, the string
// resources of the instance data (for shared items), and information about